### Corpus Editor

The corpus editor lists all the _data labels_ of the uploaded corpus. Data labels define the uploaded data in a structured way.

#### Document label selector

Use this dropdown to choose the _document_ label. Document data is the text to be analysed. All other data is _metadata_ (descriptive data about the text).

#### Datatype selectors

Datatypes define how the data can be compared and manipulated. The datatype of each label will be inferred by the Corpus Loader, but they can be changed as needed. Some values aren't compatible with some data types. For instance, "hello" cannot be interpreted as an integer. The most general data type (compatible with the most values) is text.

The _document_ label must have the text datatype.

#### Include checkbox

The include checkbox indicates whether a data label will be included in the corpus. By default, all metadata is not included. Check the box for a data label to include its data in the corpus.
